# Step 2: Scope Applications
### On this page
  * [Identify Applications](https://help.sap.com/docs/leanix/ea/application-modernization-scope-applications#identify-applications)
  * [Save Your Results](https://help.sap.com/docs/leanix/ea/application-modernization-scope-applications#save-your-results)
  * [Tag Scoped Applications](https://help.sap.com/docs/leanix/ea/application-modernization-scope-applications#tag-scoped-applications)


A strategic approach to identifying applications suitable for transformation can optimize resources and enhance operational efficiency.
To begin your modernization, focus on determining which applications are strong candidates for transformation. Filter your inventory to identify relevant applications, and save your results for easy access and future reference. After that, document the business and technical stakeholders for each application to ensure clear ownership during the assessment.
**Tip**
Instead of assessing your entire application portfolio, we suggest you target a specific business area with reliable data to gain early insights and build a foundation for broader evaluations.
